@@ -70,8 +70,8 @@ class Products:
                     [
                         "position",
                         {
-                            "desired": "gateController/desiredPos/[0]",
-                            # "current": "gateController/currentPos/[0]",
+                            "desired": "gateController/desiredPos/positions/[0]",
+                            # "current": "gateController/currentPos/positions/[0]",
                             "state": "gateController/state",
                         },
                         "gate",
@@ -79,7 +79,8 @@ class Products:
                 ],
             },
             "saunaBox": {
-                "api_path": "/api/heat/state",
+                # TODO: read extended state only once on startup
+                "api_path": "/api/heat/extended/state",
                 # TODO: use an api map (map to semver)? Or constraints?
                 "api_level_range": [20180604, 20180604],
                 "api": {
@@ -92,6 +93,8 @@ class Products:
                         "thermostat",
                         {
                             "desired": "heat/desiredTemp",
+                            "minimum": "heat/minimumTemp",
+                            "maximum": "heat/maximumTemp",
                             "temperature": "heat/sensors/[id=0]/value",
                             "state": "heat/state",
                         },
@@ -120,6 +123,7 @@ class Products:
                 ],
             },
             "switchBox0": {
+                "model": "switchBox",
                 "api_path": "/api/relay/state",
                 "api_level_range": [20180604, 20190808],
                 "api": {
