@@ -2,15 +2,18 @@
 
 import aiohttp
 import asyncio
+import logging
 
 from . import error
 
 DEFAULT_TIMEOUT = aiohttp.ClientTimeout(total=None, sock_connect=5, sock_read=5)
 DEFAULT_PORT = 80
 
+LOGGER = logging.getLogger(__name__)
+
 
 class ApiHost:
-    def __init__(self, host, port, timeout, session, loop, logger):
+    def __init__(self, host, port, timeout, session, loop, logger=LOGGER):
         self._host = host
         self._port = port
 
@@ -41,7 +44,7 @@ class ApiHost:
 
             if response.status != 200:
                 raise error.HttpError(
-                    f"Request to {self.host}:{self.port} failed with HTTP {response.status}"
+                    f"Request to {url} failed with HTTP {response.status}"
                 )
 
             return await response.json()
@@ -57,9 +60,7 @@ class ApiHost:
             ) from None
 
         except aiohttp.ClientError as ex:
-            raise error.ClientError(
-                f"API request failed to {self.host}:{self.port}: {ex}"
-            ) from ex
+            raise error.ClientError(f"API request {url} failed: {ex}") from ex
 
     async def async_api_get(self, path):
         return await self.async_request(path, self._session.get)
